summaryrefslogtreecommitdiff
path: root/Source/Core/VideoCommon/VideoBackendBase.cpp
diff options
context:
space:
mode:
authorMatthew Parlane <parlane@gmail.com>2014-03-10 09:24:09 +1300
committerMatthew Parlane <parlane@gmail.com>2014-03-10 09:24:09 +1300
commit633dc75e857d649ffab7c4398e92536bccc9e1de (patch)
treef9aa8831a0731ea246bd921d979f4bffa7f07bd0 /Source/Core/VideoCommon/VideoBackendBase.cpp
parentf4012638672472afdbd9956229f273a18a77fd77 (diff)
parentd802d392811be44d34ae9cd23f616db93e54c50f (diff)
Merge pull request #142 from Tilka/clang-modernize
Run clang-modernize and manually fix the result
Diffstat (limited to 'Source/Core/VideoCommon/VideoBackendBase.cpp')
-rw-r--r--Source/Core/VideoCommon/VideoBackendBase.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Source/Core/VideoCommon/VideoBackendBase.cpp b/Source/Core/VideoCommon/VideoBackendBase.cpp
index 36e52b6654..a2d6d19845 100644
--- a/Source/Core/VideoCommon/VideoBackendBase.cpp
+++ b/Source/Core/VideoCommon/VideoBackendBase.cpp
@@ -12,8 +12,8 @@
#include "VideoCommon/VideoBackendBase.h"
std::vector<VideoBackend*> g_available_video_backends;
-VideoBackend* g_video_backend = NULL;
-static VideoBackend* s_default_backend = NULL;
+VideoBackend* g_video_backend = nullptr;
+static VideoBackend* s_default_backend = nullptr;
#ifdef _WIN32
#include <windows.h>
@@ -36,7 +36,7 @@ static bool IsGteVista()
void VideoBackend::PopulateList()
{
- VideoBackend* backends[4] = { NULL };
+ VideoBackend* backends[4] = { nullptr };
// OGL > D3D11 > SW
#if !defined(USE_GLES) || USE_GLES3
@@ -69,7 +69,7 @@ void VideoBackend::ClearList()
void VideoBackend::ActivateBackend(const std::string& name)
{
- if (name.length() == 0) // If NULL, set it to the default backend (expected behavior)
+ if (name.length() == 0) // If nullptr, set it to the default backend (expected behavior)
g_video_backend = s_default_backend;
for (VideoBackend* backend : g_available_video_backends)